@@ -6,4 +6,6 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
+from . import dingding
 from . import wechat
+from . import feishu
