@@ -90,8 +90,6 @@ class Basics:
                 "mentioned_mobile_list": inner_mentioned_mobile_list
             }
         }
-        print('data:', data)
-
         inner_data = json.dumps(data, ensure_ascii=False)
         byte_data = inner_data.encode('utf-8')
         response = requests.post(
@@ -115,7 +113,6 @@ def send_text(
     """
     con_info = make_con_info(env_file_name=env_file_name)
     bot = Basics(con_info=con_info)
-    print(con_info)
     response = bot.send_text(
         msg=msg,
         is_at=is_at,
